@@ -125,7 +125,7 @@ class AtomeClient(object):
         if error_flag:
             return None
 
-        if req.status_code == 403 or req.status_code == 302:
+        if req.status_code == 403:
             # session is wrong, need to relogin
             self.login()
             logging.info("Got error %s, relogging (max retries: %s)", str(req.status_code), str(max_retries))
@@ -168,27 +168,15 @@ class AtomeClient(object):
 
         return self._get_info_from_server(live_url)
 
-    def get_consumption(self, period):
+    def get_consumption(self):
         """Get current data."""
-        if period not in [
-            DAILY_PERIOD_TYPE,
-            WEEKLY_PERIOD_TYPE,
-            MONTHLY_PERIOD_TYPE,
-            YEARLY_PERIOD_TYPE,
-        ]:
-            raise ValueError(
-                "Period %s out of range. Shall be either 'day', 'week', 'month' or 'year'.",
-                str(period),
-            )
         consumption_url = (
             API_BASE_URI
-            + "/api/subscription/"
+            + "/apiV2/dataJSON/"
             + self._user_id
             + "/"
             + self._user_reference
-            + API_ENDPOINT_CONSUMPTION
-            + "?period=so"
-            + period[:1]
+            + "/3months"
         )
 
         return self._get_info_from_server(consumption_url)
